@@ -24,6 +24,9 @@ model = TFAutoModelForSequenceClassification.from_pretrained("d4data/environment
 classifier = pipeline('text-classification', model=model, tokenizer=tokenizer) # cuda = 0,1 based on gpu availability
 
 #%%
+def load_embeddings():
+    return pd.read_csv('data/embeddings.csv')
+
 def predict(text_input):
     #running the classification model to predict the classes
     edd_classification = classifier(text_input)
@@ -32,8 +35,8 @@ def predict(text_input):
     
     #running due diligence ranking module
     # due diligence ranking dictionary
-    embeddings_text = similarity_model.encode([text_input])
-    embeddings_df = pd.DataFrame('data/embeddings.csv')
+    embeddings_text = np.float64(similarity_model.encode([text_input]))
+    embeddings_df = load_embeddings()
     
     
     if edd_label == 'Remediation Activities':
